// Copyright (C) 2023  Benedikt Zumtobel
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published
// by the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

package cmd

import (
	"fmt"
	"log"

	"github.com/nonce9/pwchadm/internal/pwchadm"
	"github.com/spf13/cobra"
)

var disableCmd = &cobra.Command{ //nolint:exhaustruct
	Use:   "disable",
	Short: "Disable an existing mail user account",
	Args:  cobra.ExactArgs(1),
	Run: func(cmd *cobra.Command, args []string) {
		err := pwchadm.ReadFile(&Cfg, configPath)
		if err != nil {
			log.Fatal(err)
		}

		if pwchadm.IsValidEmail(args[0]) {
			disabled := pwchadm.ChangeUserStatus(args[0], false, &Cfg)
			if disabled {
				fmt.Println("User disabled") //nolint:forbidigo
			} else {
				fmt.Println("Error disabling user") //nolint:forbidigo
			}
		} else {
			fmt.Println("Not a valid email address") //nolint:forbidigo
		}
	},
}

func init() {
	rootCmd.AddCommand(disableCmd)
}
