// Copyright (C) 2023  Benedikt Zumtobel
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published
// by the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

package cmd

import (
	_ "embed"
	"fmt"
	"log"

	"github.com/nonce9/pwchadm/internal/pwchadm"
	"github.com/spf13/cobra"
)

//go:embed embed/schema.sql
var sqlSchema string

var initCmd = &cobra.Command{ //nolint:exhaustruct
	Use:   "init",
	Short: "Initialize the database schema",
	Args:  cobra.NoArgs,
	Run: func(cmd *cobra.Command, args []string) {
		err := pwchadm.ReadFile(&Cfg, configPath)
		if err != nil {
			log.Fatal(err)
		}

		err = pwchadm.InitializeDatabase(&Cfg, sqlSchema)
		if err != nil {
			log.Fatal(err)
		}

		fmt.Println("Database successfully initialized") //nolint:forbidigo
	},
}

func init() {
	rootCmd.AddCommand(initCmd)
}
